pub fn launch(launch_config: LaunchConfig)Expand description
Launch the application.
If a custom event loop was provided via LaunchConfig::with_event_loop, it will be used.
Otherwise a default one is created.
pub fn launch(launch_config: LaunchConfig)Launch the application.
If a custom event loop was provided via LaunchConfig::with_event_loop, it will be used.
Otherwise a default one is created.